@@ -6,8 +6,9 @@ Output: xu and report of the section.
 """
 from scipy.optimize import brentq
 
-from rcdesign.is456.material.concrete import ConcreteStressBlock, Concrete
-from rcdesign.is456.material.rebar import (
+from rcdesign.is456.stressblock import LSMStressBlock
+from rcdesign.is456.concrete import Concrete
+from rcdesign.is456.rebar import (
     RebarHYSD,
     RebarLayer,
     RebarGroup,
@@ -17,24 +18,23 @@ from rcdesign.is456.material.rebar import (
 from rcdesign.is456.section import RectBeamSection
 from rcdesign.utils import rootsearch
 
-
-sb = ConcreteStressBlock("IS456 LSM")
-m20 = Concrete("M20", 20, sb)
+sb = LSMStressBlock("IS456 LSM")
+m20 = Concrete("M20", 20)
 fe415 = RebarHYSD("Fe 415", 415)
 
-t1 = RebarLayer([16, 16, 16], -35)
-t2 = RebarLayer([16, 16], -70)
-c1 = RebarLayer([16, 16], 35)
-c2 = RebarLayer([16, 16], 70)
-c3 = RebarLayer([12, 12], 100)
+t1 = RebarLayer(fe415, [16, 16, 16], -35)
+t2 = RebarLayer(fe415, [16, 16], -70)
+c1 = RebarLayer(fe415, [16, 16], 35)
+c2 = RebarLayer(fe415, [16, 16], 70)
+c3 = RebarLayer(fe415, [12, 12], 100)
 # t_st = RebarGroup(fe415, [t1, t2])
 # c_st = RebarGroup(fe415, [c1, c2])
 t_st = None
 c_st = None
 sh_st = ShearRebarGroup([Stirrups(fe415, 2, 8, 150)])
-long_st = RebarGroup(fe415, [t2, c1, t1, c2])
+long_st = RebarGroup([t2, c1, t1, c2])
 
-sec = RectBeamSection(230, 500, m20, long_st, sh_st, 25)
+sec = RectBeamSection(230, 500, sb, m20, long_st, sh_st, 25)
 # xu = 110
 xu = sec.xu(0.0035)
 # print("x_u =", xu)
